summaryrefslogtreecommitdiffstats
path: root/src/kernel/terminate.C
diff options
context:
space:
mode:
authorBill Hoffa <wghoffa@us.ibm.com>2017-04-10 14:43:51 -0500
committerDaniel M. Crowell <dcrowell@us.ibm.com>2017-05-10 15:33:40 -0400
commit240f26001382001974fff7d62367e58df3f7b1db (patch)
tree482556bd955971c05b942b6a89639f8f187360a0 /src/kernel/terminate.C
parentb947a1a4119b06ee50287854e5ea974c0926226e (diff)
downloadtalos-hostboot-240f26001382001974fff7d62367e58df3f7b1db.tar.gz
talos-hostboot-240f26001382001974fff7d62367e58df3f7b1db.zip
Include HUID of failed Proc in TI data for certain SBE errors
- Include a generic error pipleline for other future error scenarios to leverage this functionality Change-Id: Icc1399ee93157c7106d394944a3355285a8cd830 RTC: 171865 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/39072 Reviewed-by: Martin Gloff <mgloff@us.ibm.com> Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: Prachi Gupta <pragupta@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com>
Diffstat (limited to 'src/kernel/terminate.C')
-rw-r--r--src/kernel/terminate.C7
1 files changed, 5 insertions, 2 deletions
diff --git a/src/kernel/terminate.C b/src/kernel/terminate.C
index 9b3fb7278..c39f2924c 100644
--- a/src/kernel/terminate.C
+++ b/src/kernel/terminate.C
@@ -66,11 +66,14 @@ void termWritePlid(uint16_t i_source, uint32_t plid)
kernel_TIDataArea.plid = plid;
}
-void termWriteSRC(uint16_t i_source, uint16_t i_reasoncode,uint64_t i_failAddr)
+void termWriteSRC(uint16_t i_source, uint16_t i_reasoncode,uint64_t i_failAddr,
+ uint32_t i_error_data)
{
// Update the TI structure with the type of TI and who called.
kernel_TIDataArea.type = TI_WITH_SRC;
kernel_TIDataArea.source = i_source;
+ kernel_TIDataArea.error_data = i_error_data;
// Update TID data area with the SRC info we have avail
kernel_TIDataArea.src.ID = 0xBC;
OpenPOWER on IntegriCloud
@@ -66,11 +66,14 @@ void termWritePlid(uint16_t i_source, uint32_t plid)
{
- // Update the TI structure with the type of TI and who called.
+ // Update the TI structure with the type of TI, who called,
+ // and extra error data (if applicable, otherwise 0)
kernel_TIDataArea.type = TI_WITH_SRC;
kernel_TIDataArea.source = i_source;